<?php
/**
 * English Speaking Classes: Customizer
 *
 * @subpackage English Speaking Classes
 * @since 1.0
 */

use WPTRT\Customize\Section\Luzuk_English_Speaking_Classes_Button;

add_action( 'customize_register', function( $manager ) {

	$manager->register_section_type( Luzuk_English_Speaking_Classes_Button::class );

	$manager->add_section(
		new Luzuk_English_Speaking_Classes_Button( $manager, 'luzuk_english_speaking_classes_pro', [
			'title' => __( 'English Speaking Classes Pro', 'english-speaking-classes' ),
			'priority' => 0,
			'button_text' => __( 'Go Pro', 'english-speaking-classes' ),
			'button_url'  => esc_url( 'https://www.luzuk.com/product/english-speaking-course-wordpress-theme/', 'english-speaking-classes')
		] )
	);

} );

// Load the JS and CSS.
add_action( 'customize_controls_enqueue_scripts', function() {

	$version = wp_get_theme()->get( 'Version' );

	wp_enqueue_script(
		'english-speaking-classes-customize-section-button',
		get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/js/customize-controls.js' ),
		[ 'customize-controls' ],
		$version,
		true
	);

	wp_enqueue_style(
		'english-speaking-classes-customize-section-button',
		get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/css/customize-controls.css' ),
		[ 'customize-controls' ],
 		$version
	);

} );

function luzuk_english_speaking_classes_customize_register( $wp_customize ) {

	$wp_customize->add_setting('luzuk_english_speaking_classes_logo_size',array(
		'sanitize_callback'	=> 'luzuk_english_speaking_classes_sanitize_float'
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_logo_size',array(
		'type' => 'range',
		'label' => __('Logo Size','english-speaking-classes'),
		'section' => 'title_tagline'
	));

	$wp_customize->add_setting('luzuk_english_speaking_classes_logo_padding',array(
		'sanitize_callback'	=> 'esc_html'
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_logo_padding',array(
		'label' => __('Logo Margin','english-speaking-classes'),
		'section' => 'title_tagline'
	));

	$wp_customize->add_setting('luzuk_english_speaking_classes_logo_top_padding',array(
		'default' => '',
		'sanitize_callback'	=> 'luzuk_english_speaking_classes_sanitize_float'
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_logo_top_padding',array(
		'type' => 'number',
		'description' => __('Top','english-speaking-classes'),
		'section' => 'title_tagline',
	));

	$wp_customize->add_setting('luzuk_english_speaking_classes_logo_bottom_padding',array(
		'default' => '',
		'sanitize_callback'	=> 'luzuk_english_speaking_classes_sanitize_float'
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_logo_bottom_padding',array(
		'type' => 'number',
		'description' => __('Bottom','english-speaking-classes'),
		'section' => 'title_tagline',
	));

	$wp_customize->add_setting('luzuk_english_speaking_classes_logo_left_padding',array(
		'default' => '',
		'sanitize_callback'	=> 'luzuk_english_speaking_classes_sanitize_float'
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_logo_left_padding',array(
		'type' => 'number',
		'description' => __('Left','english-speaking-classes'),
		'section' => 'title_tagline',
	));

	$wp_customize->add_setting('luzuk_english_speaking_classes_logo_right_padding',array(
		'default' => '',
		'sanitize_callback'	=> 'luzuk_english_speaking_classes_sanitize_float'
 	));
 	$wp_customize->add_control('luzuk_english_speaking_classes_logo_right_padding',array(
		'type' => 'number',
		'description' => __('Right','english-speaking-classes'),
		'section' => 'title_tagline',
    ));

	$wp_customize->add_setting('luzuk_english_speaking_classes_show_site_title',array(
		'default' => true,
		'sanitize_callback'	=> 'luzuk_english_speaking_classes_sanitize_checkbox'
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_show_site_title',array(
		'type' => 'checkbox',
		'label' => __('Show / Hide Site Title','english-speaking-classes'),
		'section' => 'title_tagline'
	));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_site_title_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_site_title_color', array(
		'label' => 'Title Color',
		'section' => 'title_tagline',
	)));

	$wp_customize->add_setting('luzuk_english_speaking_classes_show_tagline',array(
		'default' => true,
		'sanitize_callback'	=> 'luzuk_english_speaking_classes_sanitize_checkbox'
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_show_tagline',array(
		'type' => 'checkbox',
		'label' => __('Show / Hide Site Tagline','english-speaking-classes'),
		'section' => 'title_tagline'
	));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_site_tagline_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_site_tagline_color', array(
		'label' => 'Tagline Color',
		'section' => 'title_tagline',
	)));

	$wp_customize->add_panel( 'luzuk_english_speaking_classes_panel_id', array(
		'priority' => 10,
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => __( 'Theme Settings', 'english-speaking-classes' ),
		'description' => __( 'Description of what this panel does.', 'english-speaking-classes' ),
	) );

	$wp_customize->add_section( 'luzuk_english_speaking_classes_theme_options_section', array(
    	'title'      => __( 'General Settings', 'english-speaking-classes' ),
		'priority'   => 30,
		'panel' => 'luzuk_english_speaking_classes_panel_id'
	) );

	$wp_customize->add_setting('luzuk_english_speaking_classes_theme_options',array(
		'default' => 'One Column',
		'sanitize_callback' => 'luzuk_english_speaking_classes_sanitize_choices'
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_theme_options',array(
		'type' => 'select',
		'label' => __('Blog Page Sidebar Layout','english-speaking-classes'),
		'section' => 'luzuk_english_speaking_classes_theme_options_section',
		'choices' => array(
		   'Left Sidebar' => __('Left Sidebar','english-speaking-classes'),
		   'Right Sidebar' => __('Right Sidebar','english-speaking-classes'),
		   'One Column' => __('One Column','english-speaking-classes'),
		   'Grid Layout' => __('Grid Layout','english-speaking-classes')
		),
	));

	$wp_customize->add_setting('luzuk_english_speaking_classes_single_post_sidebar',array(
		'default' => 'Right Sidebar',
		'sanitize_callback' => 'luzuk_english_speaking_classes_sanitize_choices'
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_single_post_sidebar',array(
        'type' => 'select',
        'label' => __('Single Post Sidebar Layout','english-speaking-classes'),
        'section' => 'luzuk_english_speaking_classes_theme_options_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','english-speaking-classes'),
            'Right Sidebar' => __('Right Sidebar','english-speaking-classes'),
            'One Column' => __('One Column','english-speaking-classes')
        ),
	));

	$wp_customize->add_setting('luzuk_english_speaking_classes_page_sidebar',array(
		'default' => 'One Column',
		'sanitize_callback' => 'luzuk_english_speaking_classes_sanitize_choices'
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_page_sidebar',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','english-speaking-classes'),
        'section' => 'luzuk_english_speaking_classes_theme_options_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','english-speaking-classes'),
            'Right Sidebar' => __('Right Sidebar','english-speaking-classes'),
            'One Column' => __('One Column','english-speaking-classes')
        ),
	));

	$wp_customize->add_setting('luzuk_english_speaking_classes_archive_page_sidebar',array(
		'default' => 'One Column',
		'sanitize_callback' => 'luzuk_english_speaking_classes_sanitize_choices'
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_archive_page_sidebar',array(
        'type' => 'select',
        'label' => __('Archive & Search Page Sidebar Layout','english-speaking-classes'),
        'section' => 'luzuk_english_speaking_classes_theme_options_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','english-speaking-classes'),
            'Right Sidebar' => __('Right Sidebar','english-speaking-classes'),
            'One Column' => __('One Column','english-speaking-classes'),
            'Grid Layout' => __('Grid Layout','english-speaking-classes')
        ),
	));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_boxfull_width', array(
		'default'           => '',
		'sanitize_callback' => 'luzuk_english_speaking_classes_sanitize_choices'
	));
	
	$wp_customize->add_control( 'luzuk_english_speaking_classes_boxfull_width', array(
		'label'    => __( 'Section Width', 'english-speaking-classes' ),
		'section'  => 'luzuk_english_speaking_classes_theme_options_section',
		'type'     => 'select',
		'choices'  => array(
			'container'  => __('Box Width', 'english-speaking-classes'),
			'container-fluid' => __('Full Width', 'english-speaking-classes'),
			'none' => __('None', 'english-speaking-classes')
		),
	));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_dropdown_anim', array(
		'default'           => 'None',
		'sanitize_callback' => 'luzuk_english_speaking_classes_sanitize_choices'
	));
	$wp_customize->add_control( 'luzuk_english_speaking_classes_dropdown_anim', array(
		'label'    => __( 'Menu Dropdown Animations', 'english-speaking-classes' ),
		'section'  => 'luzuk_english_speaking_classes_theme_options_section',
		'type'     => 'select',
		'choices'  => array(
			'bounceInUp'  => __('bounceInUp', 'english-speaking-classes'),
			'fadeInUp' => __('fadeInUp', 'english-speaking-classes'),
			'zoomIn'    => __('zoomIn', 'english-speaking-classes'),
			'None'    => __('None', 'english-speaking-classes')
		),
	));

	//Header
	$wp_customize->add_section( 'luzuk_english_speaking_classes_header' , array(
    	'title'    => __( 'Header Settings', 'english-speaking-classes' ),
		'priority' => null,
		'panel' => 'luzuk_english_speaking_classes_panel_id'
	) );

	$wp_customize->add_setting('luzuk_english_speaking_classes_header_mail',array(
    	'default' => '+101 234 456',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_header_mail',array(
	   	'type' => 'text',
	   	'label' => __('Mail','english-speaking-classes'),
	   	'section' => 'luzuk_english_speaking_classes_header',
	));

	$wp_customize->add_setting('luzuk_english_speaking_classes_header_phoneno',array(
    	'default' => '+101 234 456',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_header_phoneno',array(
	   	'type' => 'text',
	   	'label' => __('Phone Number','english-speaking-classes'),
	   	'section' => 'luzuk_english_speaking_classes_header',
	));

	$wp_customize->add_setting('luzuk_english_speaking_classes_header_btnlink',array(
    	'default' => '#',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_header_btnlink',array(
	   	'type' => 'text',
	   	'label' => __('Button Link','english-speaking-classes'),
	   	'section' => 'luzuk_english_speaking_classes_header',
	));

	
	$wp_customize->add_setting( 'luzuk_english_speaking_classes_headertopbg_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_headertopbg_col', array(
		'label' => 'Top BG Color',
		'section' => 'luzuk_english_speaking_classes_header',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_headerbottombg_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_headerbottombg_col', array(
		'label' => 'Bottom BG Color',
		'section' => 'luzuk_english_speaking_classes_header',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_headermailicon_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_headermailicon_col', array(
		'label' => 'Mail Icon Color',
		'section' => 'luzuk_english_speaking_classes_header',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_headermailtext_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_headermailtext_col', array(
		'label' => 'Mail Color',
		'section' => 'luzuk_english_speaking_classes_header',
	)));


	$wp_customize->add_setting( 'luzuk_english_speaking_classes_headertopphoneicon_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_headertopphoneicon_col', array(
		'label' => 'Phone Icon Color',
		'section' => 'luzuk_english_speaking_classes_header',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_headertopphonenumber_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_headertopphonenumber_col', array(
		'label' => 'Phone Number Color',
		'section' => 'luzuk_english_speaking_classes_header',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_menu_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_menu_color', array(
		'label' => 'Menu Color',
		'section' => 'luzuk_english_speaking_classes_header',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_menuhover_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_menuhover_color', array(
		'label' => 'Menu Hover Color',
		'section' => 'luzuk_english_speaking_classes_header',
	)));


	$wp_customize->add_setting( 'luzuk_english_speaking_classes_submenu_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_submenu_color', array(
		'label' => 'Submenu Text Color',
		'section' => 'luzuk_english_speaking_classes_header',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_submenubg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_submenubg_color', array(
		'label' => 'Submenu BG Color',
		'section' => 'luzuk_english_speaking_classes_header',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_submenuboxbrd_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_submenuboxbrd_color', array(
		'label' => 'Submenu Box Border Color',
		'section' => 'luzuk_english_speaking_classes_header',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_submenuhover_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_submenuhover_color', array(
		'label' => 'Submenu Text Hover Color',
		'section' => 'luzuk_english_speaking_classes_header',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_submenubghrv_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_submenubghrv_color', array(
		'label' => 'Submenu BG Hover Color',
		'section' => 'luzuk_english_speaking_classes_header',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_headerbtntext_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_headerbtntext_color', array(
		'label' => 'Button Text Color',
		'section' => 'luzuk_english_speaking_classes_header',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_headerbtnbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_headerbtnbg_color', array(
		'label' => 'Button BG Color',
		'section' => 'luzuk_english_speaking_classes_header',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_btntexthrv_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_btntexthrv_color', array(
		'label' => 'Button Text Hover Color',
		'section' => 'luzuk_english_speaking_classes_header',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_btnbghrv_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_btnbghrv_color', array(
		'label' => 'Button BG Hover Color',
		'section' => 'luzuk_english_speaking_classes_header',
	)));


	//home page slider
	$wp_customize->add_section( 'luzuk_english_speaking_classes_slider_section' , array(
    	'title'    => __( 'Slider Settings', 'english-speaking-classes' ),
		'description'=> __('<b>Note :</b> Please Add Image in 750*700 Ratio.','english-speaking-classes'),
		'priority' => null,
		'panel' => 'luzuk_english_speaking_classes_panel_id'
	) );

	$wp_customize->add_setting('luzuk_english_speaking_classes_slider_hide_show',array(
    	'default' => false,
    	'sanitize_callback'	=> 'luzuk_english_speaking_classes_sanitize_checkbox'
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_slider_hide_show',array(
	   	'type' => 'checkbox',
	   	'label' => __('Show / Hide Slider','english-speaking-classes'),
	   	'section' => 'luzuk_english_speaking_classes_slider_section',
	));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_slider_effect', array(
		'default'           => '',
		'sanitize_callback' => 'luzuk_english_speaking_classes_sanitize_choices'
	));
	$wp_customize->add_control( 'luzuk_english_speaking_classes_slider_effect', array(
		'label'    => __( 'Onload Transactions Effects', 'english-speaking-classes' ),
		'section'  => 'luzuk_english_speaking_classes_slider_section',
		'type'     => 'select',
		'choices'  => array(
			'bounceInLeft'  => __('bounceInLeft', 'english-speaking-classes'),
			'bounceInRight' => __('bounceInRight', 'english-speaking-classes'),
			'bounceInUp'    => __('bounceInUp', 'english-speaking-classes'),
			'bounceInDown'    => __('bounceInDown', 'english-speaking-classes'),
			'zoomIn'  => __('zoomIn', 'english-speaking-classes'),
			'zoomOut' => __('zoomOut', 'english-speaking-classes'),
			'fadeInDown'    => __('fadeInDown', 'english-speaking-classes'),
			'fadeInUp'    => __('fadeInUp', 'english-speaking-classes'),
			'fadeInLeft'  => __('fadeInLeft', 'english-speaking-classes'),
			'fadeInRight' => __('fadeInRight', 'english-speaking-classes'),
			'flip-up'    => __('flip-up', 'english-speaking-classes'),
			'none'    => __('none', 'english-speaking-classes')
		),
	));

	for ( $count = 1; $count <= 4; $count++ ) {
		$wp_customize->add_setting( 'luzuk_english_speaking_classes_slider' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'luzuk_english_speaking_classes_sanitize_dropdown_pages'
		));
		$wp_customize->add_control( 'luzuk_english_speaking_classes_slider' . $count, array(
			'label' => __('Select Slider Image Page', 'english-speaking-classes' ),
			'section' => 'luzuk_english_speaking_classes_slider_section',
			'type' => 'dropdown-pages'
		));
	}


	$wp_customize->add_setting('luzuk_english_speaking_classes_slider_excerpt_length',array(
		'default' => '15',
		'sanitize_callback'	=> 'luzuk_english_speaking_classes_sanitize_float'
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_slider_excerpt_length',array(
		'type' => 'number',
		'label' => __('Description Excerpt Length','english-speaking-classes'),
		'section' => 'luzuk_english_speaking_classes_slider_section',
	));

	$wp_customize->add_setting('luzuk_english_speaking_classes_sliderbtntext',array(
    	'default' => 'Book Now and Get 25% Discount',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_sliderbtntext',array(
	   	'type' => 'text',
	   	'label' => __('Button Text','english-speaking-classes'),
	   	'section' => 'luzuk_english_speaking_classes_slider_section',
	));

	$wp_customize->add_setting('luzuk_english_speaking_classes_sliderbtnlink',array(
    	'default' => '#',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('luzuk_english_speaking_classes_sliderbtnlink',array(
	   	'type' => 'url',
	   	'label' => __('Button Link','english-speaking-classes'),
	   	'section' => 'luzuk_english_speaking_classes_slider_section',
	));


	$wp_customize->add_setting( 'luzuk_english_speaking_classes_slider_bg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_slider_bg_color', array(
		'label' => 'BG Color',
		'section' => 'luzuk_english_speaking_classes_slider_section',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_slider_contentboxbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_slider_contentboxbg_color', array(
		'label' => 'Box BG Color',
		'section' => 'luzuk_english_speaking_classes_slider_section',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_slider_title_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_slider_title_color', array(
		'label' => 'Title Color',
		'section' => 'luzuk_english_speaking_classes_slider_section',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_slider_description_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_slider_description_color', array(
		'label' => 'Description Color',
		'section' => 'luzuk_english_speaking_classes_slider_section',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_slider_btntext_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_slider_btntext_color', array(
		'label' => 'Button Text Color',
		'section' => 'luzuk_english_speaking_classes_slider_section',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_slider_btnbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_slider_btnbg_color', array(
		'label' => 'Button BG Color',
		'section' => 'luzuk_english_speaking_classes_slider_section',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_slider_btntexthrv_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_slider_btntexthrv_color', array(
		'label' => 'Button Hover Color',
		'section' => 'luzuk_english_speaking_classes_slider_section',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_slider_btnbghrv_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_slider_btnbghrv_color', array(
		'label' => 'Button BG Hover Color',
		'section' => 'luzuk_english_speaking_classes_slider_section',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_slider_arrowlefticon_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_slider_arrowlefticon_color', array(
		'label' => 'Left Arrow Icon Color',
		'section' => 'luzuk_english_speaking_classes_slider_section',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_slider_arrowlefticonbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_slider_arrowlefticonbg_color', array(
		'label' => 'Left Arrow Icon BG Color',
		'section' => 'luzuk_english_speaking_classes_slider_section',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_slider_arrowrighticon_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_slider_arrowrighticon_color', array(
		'label' => 'Right Arrow Icon Color',
		'section' => 'luzuk_english_speaking_classes_slider_section',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_slider_arrowrighticonbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_slider_arrowrighticonbg_color', array(
		'label' => 'Right Arrow Icon BG Color',
		'section' => 'luzuk_english_speaking_classes_slider_section',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_slider_arrowiconhrv_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_slider_arrowiconhrv_color', array(
		'label' => 'Arrow Icon Hover Color',
		'section' => 'luzuk_english_speaking_classes_slider_section',
	)));


	//Aboutus Section
	$wp_customize->add_section('luzuk_english_speaking_classes_aboutus_section',array(
		'title'	=> __('Aboutus Settings','english-speaking-classes'),
		'description'=> __('<b>Note :</b> This section will appear below the slider.','english-speaking-classes'),
		'panel' => 'luzuk_english_speaking_classes_panel_id',
	));

	$wp_customize->add_setting(
    	'luzuk_english_speaking_classes_aboutus_leftimage1',
	    array(
	        'sanitize_callback' => 'esc_url_raw'
	    )
	);
	$wp_customize->add_control(
	    new WP_Customize_Image_Control(
	        $wp_customize,
	        'luzuk_english_speaking_classes_aboutus_leftimage1',
	        array(
			    'label'   		=> __('Left Image 1','english-speaking-classes'),
				'description'   		=> __('Image size 750*800','english-speaking-classes'),
	            'section' => 'luzuk_english_speaking_classes_aboutus_section',
	            'settings' => 'luzuk_english_speaking_classes_aboutus_leftimage1',
	        )
	    )
	);

	$wp_customize->add_setting(
    	'luzuk_english_speaking_classes_aboutus_leftimage2',
	    array(
	        'sanitize_callback' => 'esc_url_raw'
	    )
	);
	$wp_customize->add_control(
	    new WP_Customize_Image_Control(
	        $wp_customize,
	        'luzuk_english_speaking_classes_aboutus_leftimage2',
	        array(
			    'label'   		=> __('Left Image 2','english-speaking-classes'),
				'description'   		=> __('Image size 750*800','english-speaking-classes'),
	            'section' => 'luzuk_english_speaking_classes_aboutus_section',
	            'settings' => 'luzuk_english_speaking_classes_aboutus_leftimage2',
	        )
	    )
	);

	$wp_customize->add_setting(
    	'luzuk_english_speaking_classes_aboutus_rightheadingbgimg',
	    array(
	        'sanitize_callback' => 'esc_url_raw'
	    )
	);
	$wp_customize->add_control(
	    new WP_Customize_Image_Control(
	        $wp_customize,
	        'luzuk_english_speaking_classes_aboutus_rightheadingbgimg',
	        array(
			    'label'   		=> __('Heading BG Image','english-speaking-classes'),
				'description'   		=> __('Image size 750*800','english-speaking-classes'),
	            'section' => 'luzuk_english_speaking_classes_aboutus_section',
	            'settings' => 'luzuk_english_speaking_classes_aboutus_rightheadingbgimg',
	        )
	    )
	);

	
	$wp_customize->add_setting('luzuk_english_speaking_classes_aboutusheading',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_aboutusheading',array(
	   	'type' => 'text',
	   	'label' => __('Heading','english-speaking-classes'),
	   	'section' => 'luzuk_english_speaking_classes_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_english_speaking_classes_aboutustitle',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_aboutustitle',array(
	   	'type' => 'text',
	   	'label' => __('Title','english-speaking-classes'),
	   	'section' => 'luzuk_english_speaking_classes_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_english_speaking_classes_aboutusdescription1',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_aboutusdescription1',array(
	   	'type' => 'text',
	   	'label' => __('Description','english-speaking-classes'),
	   	'section' => 'luzuk_english_speaking_classes_aboutus_section',
	));


	$wp_customize->add_setting('luzuk_english_speaking_classes_aboutuslist1',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_aboutuslist1',array(
	   	'type' => 'text',
	   	'label' => __('List 1 Text','english-speaking-classes'),
	   	'section' => 'luzuk_english_speaking_classes_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_english_speaking_classes_aboutuslist2',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_aboutuslist2',array(
	   	'type' => 'text',
	   	'label' => __('List 2 Text','english-speaking-classes'),
	   	'section' => 'luzuk_english_speaking_classes_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_english_speaking_classes_aboutuslist3',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_aboutuslist3',array(
	   	'type' => 'text',
	   	'label' => __('List 3 Text','english-speaking-classes'),
	   	'section' => 'luzuk_english_speaking_classes_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_english_speaking_classes_aboutuslist4',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_aboutuslist4',array(
	   	'type' => 'text',
	   	'label' => __('List 4 Text','english-speaking-classes'),
	   	'section' => 'luzuk_english_speaking_classes_aboutus_section',
	));
	
	$wp_customize->add_setting('luzuk_english_speaking_classes_aboutuslist5',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_aboutuslist5',array(
	   	'type' => 'text',
	   	'label' => __('List 5 Text','english-speaking-classes'),
	   	'section' => 'luzuk_english_speaking_classes_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_english_speaking_classes_aboutuslist6',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_aboutuslist6',array(
	   	'type' => 'text',
	   	'label' => __('List 6 Text','english-speaking-classes'),
	   	'section' => 'luzuk_english_speaking_classes_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_english_speaking_classes_aboutuslist7',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_aboutuslist7',array(
	   	'type' => 'text',
	   	'label' => __('List 7 Text','english-speaking-classes'),
	   	'section' => 'luzuk_english_speaking_classes_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_english_speaking_classes_aboutuslist8',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_aboutuslist8',array(
	   	'type' => 'text',
	   	'label' => __('List 8 Text','english-speaking-classes'),
	   	'section' => 'luzuk_english_speaking_classes_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_english_speaking_classes_aboutus_btnlink',array(
    	'default' => '#',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_aboutus_btnlink',array(
	   	'type' => 'text',
	   	'label' => __('Button Link','english-speaking-classes'),
	   	'section' => 'luzuk_english_speaking_classes_aboutus_section',
	));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_aboutusheading_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_aboutusheading_color', array(
		'label' => 'Heading Color',
		'section' => 'luzuk_english_speaking_classes_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_aboutusheadingbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_aboutusheadingbg_color', array(
		'label' => 'Heading BG Color',
		'section' => 'luzuk_english_speaking_classes_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_aboutusheadingboxbrd_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_aboutusheadingboxbrd_color', array(
		'label' => 'Heading Box Border Color',
		'section' => 'luzuk_english_speaking_classes_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_aboutustitle_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_aboutustitle_color', array(
		'label' => 'Title Color',
		'section' => 'luzuk_english_speaking_classes_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_aboutusdescription_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_aboutusdescription_color', array(
		'label' => 'Description Color',
		'section' => 'luzuk_english_speaking_classes_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_aboutuslists_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_aboutuslists_color', array(
		'label' => 'Lists Color',
		'section' => 'luzuk_english_speaking_classes_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_aboutuslistsicon_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_aboutuslistsicon_color', array(
		'label' => 'Lists Icon Color',
		'section' => 'luzuk_english_speaking_classes_aboutus_section',
	)));
	

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_aboutusbtntext_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_aboutusbtntext_color', array(
		'label' => 'Button Text Color',
		'section' => 'luzuk_english_speaking_classes_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_aboutusbtnbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_aboutusbtnbg_color', array(
		'label' => 'Button BG Color',
		'section' => 'luzuk_english_speaking_classes_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_aboutusbtntexthrv_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_aboutusbtntexthrv_color', array(
		'label' => 'Button Text Hover Color',
		'section' => 'luzuk_english_speaking_classes_aboutus_section',
	)));
	
	$wp_customize->add_setting( 'luzuk_english_speaking_classes_aboutusbtnbghrv_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_aboutusbtnbghrv_color', array(
		'label' => 'Button BG Hover Color',
		'section' => 'luzuk_english_speaking_classes_aboutus_section',
	)));
	
	
	//Service Section
	$wp_customize->add_section('luzuk_english_speaking_classes_service_section',array(
		'title'	=> __('Service Settings','english-speaking-classes'),
		'description'=> __('<b>Note :</b> This section will appear below the About Us.','english-speaking-classes'),
		'panel' => 'luzuk_english_speaking_classes_panel_id',
	));


	$categories = get_categories();
	$cats = array();
	$i = 0;
	$cat_pst[]= 'select';
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_pst[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('luzuk_english_speaking_classes_service_category_setting',array(
		'default' => 'select',
		'sanitize_callback' => 'luzuk_english_speaking_classes_sanitize_choices',
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_service_category_setting',array(
		'type' => 'select',
		'choices' => $cat_pst,
		'label' => __('Select Category To Display Post','english-speaking-classes'),
		'section' => 'luzuk_english_speaking_classes_service_section',
	));

	$wp_customize->add_setting('luzuk_english_speaking_classes_serviceheading',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_serviceheading',array(
	   	'type' => 'text',
	   	'label' => __('Heading','english-speaking-classes'),
	   	'section' => 'luzuk_english_speaking_classes_service_section',
	));

	$wp_customize->add_setting('english_speaking_classes_number',array(
		'default'	=> '4',
		'sanitize_callback'	=> 'sanitize_text_field',
	));
	$wp_customize->add_control('english_speaking_classes_number',array(
		'label'	=> __('Number Of Services To Show In A Category','english-speaking-classes'),
		'section' => 'luzuk_english_speaking_classes_service_section',
		'type'	  => 'number'
	));

	$english_speaking_classes_number = get_theme_mod('english_speaking_classes_number', 4);
	for ($i=1; $i <= $english_speaking_classes_number; $i++) { 
	   	$wp_customize->add_setting('english_speaking_classes_feature_icon' . $i, array(
	      	'default' => 'fas fa-cog',
	      	'sanitize_callback' => 'sanitize_text_field'
	   	));
	   	$wp_customize->add_control(new Luzuk_English_Speaking_Classes_Fontawesome_Icon_Chooser($wp_customize, 'english_speaking_classes_feature_icon' . $i, array(
	      	'section' => 'luzuk_english_speaking_classes_service_section',
	      	'type' => 'icon',
	      	'label' => esc_html__('Service Icon ', 'english-speaking-classes') . $i
	  	)));
	}

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_service_heading_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_service_heading_color', array(
		'label' => 'Heading Color',
		'section' => 'luzuk_english_speaking_classes_service_section',
	)));

	
	$wp_customize->add_setting( 'luzuk_english_speaking_classes_service_title_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_service_title_color', array(
		'label' => 'Title Color',
		'section' => 'luzuk_english_speaking_classes_service_section',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_service_description_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_service_description_color', array(
		'label' => 'Description Color',
		'section' => 'luzuk_english_speaking_classes_service_section',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_service_icon_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_service_icon_color', array(
		'label' => 'Icon Color',
		'section' => 'luzuk_english_speaking_classes_service_section',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_service_iconbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_service_iconbg_color', array(
		'label' => 'Icon BG Color',
		'section' => 'luzuk_english_speaking_classes_service_section',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_service_iconbrd_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_service_iconbrd_color', array(
		'label' => 'Icon Border Color',
		'section' => 'luzuk_english_speaking_classes_service_section',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_service_btntext_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_service_btntext_color', array(
		'label' => 'Button Text Color',
		'section' => 'luzuk_english_speaking_classes_service_section',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_service_btnbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_service_btnbg_color', array(
		'label' => 'Button BG Color',
		'section' => 'luzuk_english_speaking_classes_service_section',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_service_btntexthrv_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_service_btntexthrv_color', array(
		'label' => 'Button Text Hover Color',
		'section' => 'luzuk_english_speaking_classes_service_section',
	)));


	//Footer
    $wp_customize->add_section( 'luzuk_english_speaking_classes_footer', array(
    	'title'  => __( 'Footer Settings', 'english-speaking-classes' ),
		'priority' => null,
		'panel' => 'luzuk_english_speaking_classes_panel_id'
	) );

	$wp_customize->add_setting('luzuk_english_speaking_classes_show_back_totop',array(
       'default' => true,
       'sanitize_callback'	=> 'luzuk_english_speaking_classes_sanitize_checkbox'
    ));
    $wp_customize->add_control('luzuk_english_speaking_classes_show_back_totop',array(
       'type' => 'checkbox',
       'label' => __('Show / Hide Back to Top','english-speaking-classes'),
       'section' => 'luzuk_english_speaking_classes_footer'
    ));

    $wp_customize->add_setting('luzuk_english_speaking_classes_footer_copy', array(
		'default'           => 'Copyright © 2024 Education Wordpress Themes. All rights reserved.',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_footer_copy', array(
		'label'       => __('Copyright Text', 'english-speaking-classes'),
		'section'     => 'luzuk_english_speaking_classes_footer',
		'setting'     => 'luzuk_english_speaking_classes_footer_copy',
		'type'        => 'text',
		'description' => __('<b>This feature is only available in the premium version.</b>', 'english-speaking-classes'),
		'input_attrs' => array(
			'readonly' => 'readonly',
		),
	));	

	$wp_customize->add_setting('luzuk_english_speaking_classes_footer_copylink', array(
		'default'           => 'https://www.luzuk.com/top/wordpress-themes/education/',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('luzuk_english_speaking_classes_footer_copylink', array(
		'label'    => __('Copyright Link', 'english-speaking-classes'),
		'section'  => 'luzuk_english_speaking_classes_footer',
		'setting'  => 'luzuk_english_speaking_classes_footer_copylink',
		'type'     => 'text',
		'input_attrs' => array(
			'readonly' => 'readonly',
		),
	));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_footertext_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_footertext_color', array(
		'label' => 'Text Color',
		'section' => 'luzuk_english_speaking_classes_footer',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_footerbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_footerbg_color', array(
		'label' => 'BG Color',
		'section' => 'luzuk_english_speaking_classes_footer',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_footercopyright_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_footercopyright_color', array(
		'label' => 'Copyright Color',
		'section' => 'luzuk_english_speaking_classes_footer',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_footerscrolltotoptext_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_footerscrolltotoptext_color', array(
		'label' => 'Scroll To Top Text Color',
		'section' => 'luzuk_english_speaking_classes_footer',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_footerscrolltotopbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_footerscrolltotopbg_color', array(
		'label' => 'Scroll To Top BG Color',
		'section' => 'luzuk_english_speaking_classes_footer',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_footerscrolltotoptexthover_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_footerscrolltotoptexthover_color', array(
		'label' => 'Scroll To Top Text Hover Color',
		'section' => 'luzuk_english_speaking_classes_footer',
	)));

	$wp_customize->add_setting( 'luzuk_english_speaking_classes_footerscrolltotophover_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_english_speaking_classes_footerscrolltotophover_color', array(
		'label' => 'Scroll To Top Hover Color',
		'section' => 'luzuk_english_speaking_classes_footer',
	)));




	

	$wp_customize->get_setting( 'blogname' )->transport          = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport   = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport  = 'postMessage';

	$wp_customize->selective_refresh->add_partial( 'blogname', array(
		'selector' => '.site-title a',
		'render_callback' => 'luzuk_english_speaking_classes_customize_partial_blogname',
	) );
	$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
		'selector' => '.site-description',
		'render_callback' => 'luzuk_english_speaking_classes_customize_partial_blogdescription',
	) );
}
add_action( 'customize_register', 'luzuk_english_speaking_classes_customize_register' );

function luzuk_english_speaking_classes_customize_partial_blogname() {
	bloginfo( 'name' );
}

function luzuk_english_speaking_classes_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

if (class_exists('WP_Customize_Control')) {

   	class Luzuk_English_Speaking_Classes_Fontawesome_Icon_Chooser extends WP_Customize_Control {

      	public $type = 'icon';

      	public function render_content() { ?>
	     	<label>
	            <span class="customize-control-title">
	               <?php echo esc_html($this->label); ?>
	            </span>

	            <?php if ($this->description) { ?>
	                <span class="description customize-control-description">
	                   <?php echo wp_kses_post($this->description); ?>
	                </span>
	            <?php } ?>

	            <div class="english-speaking-classes-selected-icon">
	                <i class="fa <?php echo esc_attr($this->value()); ?>"></i>
	                <span><i class="fa fa-angle-down"></i></span>
	            </div>

	            <ul class="english-speaking-classes-icon-list clearfix">
	                <?php
	                $luzuk_english_speaking_classes_font_awesome_icon_array = luzuk_english_speaking_classes_font_awesome_icon_array();
	                foreach ($luzuk_english_speaking_classes_font_awesome_icon_array as $luzuk_english_speaking_classes_font_awesome_icon) {
	                   $icon_class = $this->value() == $luzuk_english_speaking_classes_font_awesome_icon ? 'icon-active' : '';
	                   echo '<li class=' . esc_attr($icon_class) . '><i class="' . esc_attr($luzuk_english_speaking_classes_font_awesome_icon) . '"></i></li>';
	                }
	                ?>
	            </ul>
	            <input type="hidden" value="<?php $this->value(); ?>" <?php $this->link(); ?> />
	        </label>
	        <?php
      	}
  	}
}
function luzuk_english_speaking_classes_customizer_script() {
   wp_enqueue_style( 'font-awesome-1', esc_url(get_template_directory_uri()).'/assets/css/fontawesome-all.css');
}
add_action( 'customize_controls_enqueue_scripts', 'luzuk_english_speaking_classes_customizer_script' );